Learn R Programming

tweetcheck (version 0.1.0)

tweet_get_mentions: Extract mentions from a tweet

Description

Extract mentions from a tweet

Usage

tweet_get_mentions(x)

Value

A list with length(x) elements, where each element is a character vector of mentions. Mentions have the '@' character removed.

Arguments

x

A character vector of tweets to extract mentions for

Examples

Run this code
tweet_get_mentions(c("No mentions", "One mention @_wurli"))

Run the code above in your browser using DataLab