powered by
Extract mentions from a tweet
tweet_get_mentions(x)
A list with length(x) elements, where each element is a character vector of mentions. Mentions have the '@' character removed.
length(x)
A character vector of tweets to extract mentions for
tweet_get_mentions(c("No mentions", "One mention @_wurli"))
Run the code above in your browser using DataLab